#ifndef MOO_DIALOGS_P_H
#define MOO_DIALOGS_P_H

#include <moo/debug.h>
#include <QtCore>

namespace moo {
namespace impl {

class MyProcess : public QProcess {
    Q_OBJECT

    int exitCode;
    QByteArray childOut;
    QByteArray childErr;
    QEventLoop loop;

private Q_SLOTS:
    void readyReadStandardOutput()
    {
        childOut += readAllStandardOutput();
    }

    void readyReadStandardError()
    {
        childOut += readAllStandardError();
    }

    void childError(QProcess::ProcessError)
    {
        exitCode = -1;
        loop.exit();
    }

    void childFinished(int code, QProcess::ExitStatus)
    {
        exitCode = code;
        loop.exit();
    }

private:
    MyProcess() :
        exitCode(0)
    {
    }

    ~MyProcess()
    {
        loop.exit();
    }

public:
    static int run(QStringList &args, QByteArray &out, QByteArray &err)
    {
        MyProcess *p = new MyProcess;

        mDebug("devel") << "starting a process: " << args;

        p->connect(p, SIGNAL(error(QProcess::ProcessError)),
                   SLOT(childError(QProcess::ProcessError)));
        p->connect(p, SIGNAL(finished(int, QProcess::ExitStatus)),
                   SLOT(childFinished(int, QProcess::ExitStatus)));
        p->connect(p, SIGNAL(readyReadStandardOutput()),
                   SLOT(readyReadStandardOutput()));
        p->connect(p, SIGNAL(readyReadStandardError()),
                   SLOT(readyReadStandardError()));

        p->start(args.at(0), args.mid(1));

        p->loop.exec();

        out = p->childOut;
        err = p->childErr;

        p->deleteLater();
        return p->exitCode;
    }
};

}
}

#endif // MOO_DIALOGS_P_H
