#ifndef MOO_DOC_WINDOW_P_H
#define MOO_DOC_WINDOW_P_H

#include <moo/docwindow.h>
#include <moo/document.h>
#include <QUrl>
#include <QtGui>

namespace moo {

class RecentMenuPrivate;
class RecentMenu : public QMenu {
    Q_OBJECT
    friend class RecentMenuPrivate;
    RecentMenuPrivate *impl;

public:
    RecentMenu(DocumentWindow *window, QWidget *parent = 0);
    ~RecentMenu();

    static void addUrl(const QUrl &url);
private:
    static void clearList();
    static void queueUpdateAll();

private Q_SLOTS:
    void queueUpdate();
    void updateMenu();
    void clearMenu();
    void actionTriggered();
};

class DocumentWindowPrivate {
    M_DECLARE_PUBLIC(DocumentWindow)

    static QList<DocumentWindow*> windows;

    DocumentWindowPrivate(DocumentWindow *q) :
        pub(q)
    {
        windows.append(q);
    }

    ~DocumentWindowPrivate()
    {
        M_Q(DocumentWindow);
        windows.removeAll(q);
    }

    static DocumentWindow *find(const QUrl &url)
    {
//         QString absname = QFileInfo(filename).absoluteFilePath();
        QString absname = url.toString(QUrl::RemovePassword | QUrl::StripTrailingSlash); // XXX
        foreach (DocumentWindow *w, windows)
            if (w->document()->url().toString(QUrl::RemovePassword | QUrl::StripTrailingSlash) == absname)
                return w;
        return 0;
    }
};

}

#endif // MOO_DOC_WINDOW_P_H
